@@ -1,23 +1,8 @@
-#ifndef BOOST_NO_AUTO_PTR
-#define BOOST_NO_AUTO_PTR
-#endif
-
-#ifndef BOOST_MATH_PROMOTE_DOUBLE_POLICY
-#define BOOST_MATH_PROMOTE_DOUBLE_POLICY false
-#else
-#undef BOOST_MATH_PROMOTE_DOUBLE_POLICY
-#define BOOST_MATH_PROMOTE_DOUBLE_POLICY false
-#endif
-
-#ifndef BOOST_ALLOW_DEPRECATED_HEADERS
-#define BOOST_ALLOW_DEPRECATED_HEADERS
-#endif
-
-#include "dvine_reg_selector.hpp"
-#include <RcppThread.h>
-#include <kde1d-wrappers.hpp>
 #include <vinecopulib-wrappers.hpp>
 #include <vinecopulib/bicop/fit_controls.hpp>
+#include <RcppThread.h>
+#include <kde1d-wrappers.hpp>
+#include "dvine_reg_selector.hpp"
 
 using namespace vinecopulib;
 
@@ -70,7 +55,8 @@ select_dvine_cpp(const Eigen::MatrixXd& data,
                  std::string selcrit,
                  const Eigen::VectorXd& weights,
                  double psi0,
-                 bool preselect_families,
+                 bool presel,
+                 bool allow_rotations,
                  size_t cores,
                  const std::vector<std::string>& var_types)
 {
@@ -86,7 +72,8 @@ select_dvine_cpp(const Eigen::MatrixXd& data,
                               selcrit,
                               weights,
                               psi0,
-                              preselect_families,
+                              presel,
+                              allow_rotations,
                               cores);
 
     // select the model -----------------------------------------
