@@ -76,11 +76,11 @@ test_that("works with continuous response", {
   expect_equal(cll(fit, dat), fit$stats$cll, 0.1)
 })
 
-# test_that("works with discrete response", {
-#   dat$y <- as.ordered(round(dat$y))
-#   fit <- vinereg(y ~ ., dat, fam = "gauss")
-#   expect_equal(cll(fit, dat), fit$stats$cll, 5) # very lenient for now
-# })
+test_that("works with discrete response", {
+  dat$y <- as.ordered(round(dat$y))
+  fit <- vinereg(y ~ ., dat, fam = "gauss")
+  expect_equal(cll(fit, dat), fit$stats$cll, 5) # very lenient for now
+})
 
 test_that("works on uscale", {
   dat[] <- runif(nrow(dat) * ncol(dat))
